import { LitElement } from 'lit';
/**
 * @element uui-icon
 * @fires {UUIIconRequestEvent} icon_request - fires when the name property is defined to retrieve the icon source.
 * @description - Icon component for displaying icons.
 * @cssprop --uui-icon-color - overwrite the icon color.
 * @see UUIIconRegistryElement Ideally used together with a icon registry.
 */
export declare class UUIIconElement extends LitElement {
    private _name;
    private _retrievedNameIcon;
    private _nameSvg;
    /**
     * An alternate description to use for assistive devices.
     * If omitted, the icon will be considered presentational and ignored by assistive devices.
     * @type {string}
     * @attr
     * @default
     */
    label: string;
    /**
     * Icon name is used to retrieve the icon from a parent Icon Registry.
     * If no Icon Registry responds to the given name, the fallback svg will be used.
     * @type {string}
     * @attr
     * @default null
     */
    get name(): string | null;
    set name(newValue: string | null);
    private requestIcon;
    /**
     * Define the raw SVG string to be displayed by this component.
     * @type {string}
     * @attr
     * @default null
     */
    svg: string | null;
    /**
     * Fallback SVG is a raw SVG string, this is used then 'name' hasn't been accepted by any parent Icon Registry.
     * @type {string}
     * @attr
     * @default null
     */
    fallback: string | null;
    private _useFallback;
    connectedCallback(): void;
    disconnectedCallback(): void;
    firstUpdated(): void;
    render(): import("lit-html").TemplateResult<1>;
    static styles: import("lit").CSSResult[];
}
declare global {
    interface HTMLElementTagNameMap {
        'uui-icon': UUIIconElement;
    }
}
